@@ -4,8 +4,7 @@
     SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#ifndef LIBKGAPI2_DRIVETEAMDRIVE_H
-#define LIBKGAPI2_DRIVETEAMDRIVE_H
+#pragma once
 
 #include "types.h"
 #include "object.h"
@@ -483,4 +482,3 @@ class KGAPIDRIVE_EXPORT Teamdrive: public KGAPI2::Object
 
 } /* namespace KGAPI2 */
 
-#endif // LIBKGAPI2_DRIVETEAMDRIVE_H
